==> ejc-cfs-api-3.0.0-20240306.062532-178-sources.jar: com/ejianc/foundation/cfs/vo/CustomListVO.java <==
package com.ejianc.foundation.cfs.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 配置列表项
 * 
 * @author lyj
 *
 */
public class CustomListVO extends BaseVO {

	private static final long serialVersionUID = -8878993756357134195L;

	private Long appId; // 应用Id

	private Long columnId; // 列id

	private String columnProperty; // 列属性

	private String columnName; // 列名称

	private String columnType; // 列类型

	private String columnFormat; // 列显示格式

	private Boolean innerFilter; // 是否支持搜索

	private Boolean total; // 是否数据汇总

	private Boolean viewDetail; // 是否支持查看详情

	private String align; // 对齐方式

	private String suffixStr; // 显示后缀

	private String customize; // 自定义

	private Integer sequence; // 排序号

	private Boolean subExportRelation; // 导出数据该字段是否关联到子表

	public Boolean getSubExportRelation() {
		return subExportRelation;
	}

	public void setSubExportRelation(Boolean subExportRelation) {
		this.subExportRelation = subExportRelation;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getColumnId() {
		return columnId;
	}

	public void setColumnId(Long columnId) {
		this.columnId = columnId;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public String getColumnProperty() {
		return columnProperty;
	}

	public void setColumnProperty(String columnProperty) {
		this.columnProperty = columnProperty;
	}

	public String getColumnType() {
		return columnType;
	}

	public void setColumnType(String columnType) {
		this.columnType = columnType;
	}

	public String getColumnFormat() {
		return columnFormat;
	}

	public void setColumnFormat(String columnFormat) {
		this.columnFormat = columnFormat;
	}

	public Boolean getInnerFilter() {
		return innerFilter;
	}

	public void setInnerFilter(Boolean innerFilter) {
		this.innerFilter = innerFilter;
	}

	public Boolean getTotal() {
		return total;
	}

	public void setTotal(Boolean total) {
		this.total = total;
	}

	public Boolean getViewDetail() {
		return viewDetail;
	}

	public void setViewDetail(Boolean viewDetail) {
		this.viewDetail = viewDetail;
	}

	public String getAlign() {
		return align;
	}

	public void setAlign(String align) {
		this.align = align;
	}

	public String getSuffixStr() {
		return suffixStr;
	}

	public void setSuffixStr(String suffixStr) {
		this.suffixStr = suffixStr;
	}

	public String getCustomize() {
		return customize;
	}

	public void setCustomize(String customize) {
		this.customize = customize;
	}

}

==> ejc-cfs-api-3.0.0-20240423.103634-210-sources.jar: com/ejianc/foundation/cfs/vo/CustomListVO.java <==
package com.ejianc.foundation.cfs.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 配置列表项
 * 
 * @author lyj
 *
 */
public class CustomListVO extends BaseVO {

	private static final long serialVersionUID = -8878993756357134195L;

	private Long appId; // 应用Id

	private Long columnId; // 列id

	private String columnProperty; // 列属性

	private String columnName; // 列名称

	private String columnType; // 列类型

	private String columnFormat; // 列显示格式

	private Boolean innerFilter; // 是否支持搜索

	private Boolean total; // 是否数据汇总

	private Boolean nameCol; // 是否名称字段

	private Boolean codeCol; // 是否编码字段

	private Boolean viewDetail; // 是否支持查看详情

	private String align; // 对齐方式

	private String suffixStr; // 显示后缀

	private String customize; // 自定义

	private Integer sequence; // 排序号

	private Boolean subExportRelation; // 导出数据该字段是否关联到子表

	public Boolean getSubExportRelation() {
		return subExportRelation;
	}

	public void setSubExportRelation(Boolean subExportRelation) {
		this.subExportRelation = subExportRelation;
	}

	public Long getAppId() {
		return appId;
	}

	public void setAppId(Long appId) {
		this.appId = appId;
	}

	public Long getColumnId() {
		return columnId;
	}

	public void setColumnId(Long columnId) {
		this.columnId = columnId;
	}

	public String getColumnName() {
		return columnName;
	}

	public void setColumnName(String columnName) {
		this.columnName = columnName;
	}

	public Integer getSequence() {
		return sequence;
	}

	public void setSequence(Integer sequence) {
		this.sequence = sequence;
	}

	public String getColumnProperty() {
		return columnProperty;
	}

	public void setColumnProperty(String columnProperty) {
		this.columnProperty = columnProperty;
	}

	public String getColumnType() {
		return columnType;
	}

	public void setColumnType(String columnType) {
		this.columnType = columnType;
	}

	public String getColumnFormat() {
		return columnFormat;
	}

	public void setColumnFormat(String columnFormat) {
		this.columnFormat = columnFormat;
	}

	public Boolean getInnerFilter() {
		return innerFilter;
	}

	public void setInnerFilter(Boolean innerFilter) {
		this.innerFilter = innerFilter;
	}

	public Boolean getTotal() {
		return total;
	}

	public void setTotal(Boolean total) {
		this.total = total;
	}

	public Boolean getViewDetail() {
		return viewDetail;
	}

	public void setViewDetail(Boolean viewDetail) {
		this.viewDetail = viewDetail;
	}

	public String getAlign() {
		return align;
	}

	public void setAlign(String align) {
		this.align = align;
	}

	public String getSuffixStr() {
		return suffixStr;
	}

	public void setSuffixStr(String suffixStr) {
		this.suffixStr = suffixStr;
	}

	public String getCustomize() {
		return customize;
	}

	public void setCustomize(String customize) {
		this.customize = customize;
	}

	public Boolean getNameCol() {
		return nameCol;
	}

	public void setNameCol(Boolean nameCol) {
		this.nameCol = nameCol;
	}

	public Boolean getCodeCol() {
		return codeCol;
	}

	public void setCodeCol(Boolean codeCol) {
		this.codeCol = codeCol;
	}
}
